<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>AppItemMenu</name>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Pin to Top</source>
        <translation>Épingler en haut</translation>
    </message>
    <message>
        <source>Move to Top</source>
        <translation>Déplacer vers le haut</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Retirer des favoris</translation>
    </message>
    <message>
        <source>Add to favorites</source>
        <translation>Ajouter aux favoris</translation>
    </message>
    <message>
        <source>Remove from desktop</source>
        <translation>Supprimer du bureau</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Envoyer sur le bureau</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Supprimer du dock</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Épingler au dock</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Supprimer du démarrage</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Ajouter au démarrage</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>Utiliser un proxy</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Désactivez la mise à l&apos;échelle de l&apos;affichage</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Désinstaller</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <source>Power</source>
        <translation>Alimentation</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Full-screen Mode</source>
        <translation>Mode plein écran</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <source>Frequently Used</source>
        <translation>Utilisé souvent</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Window Mode</source>
        <translation>Mode fenêtre</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Discussion</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Graphisme</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Jeux</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Bureautique</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Développement</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Autres</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>Êtes-vous sûr de vouloir désinstaller &quot;%1&quot; ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <source>Recently Installed</source>
        <translation>Installé récemment</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <source>All Apps</source>
        <translation>Toutes les application</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Aucun résultat trouvé</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Free sorting</source>
        <translation>Tri libre</translation>
    </message>
    <message>
        <source>Sort by category</source>
        <translation>Trier par catégorie</translation>
    </message>
    <message>
        <source>Sort by name</source>
        <translation>Trier par nom</translation>
    </message>
    <message>
        <source>Sorting Mode</source>
        <translation>Mode de tri</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>Ordinateur</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation>Centre de contrôle</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Discussion</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Graphisme</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Jeux</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Bureautique</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Développement</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Autres</translation>
    </message>
    <message>
        <source>launchpad</source>
        <translation>Launchpad</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>Êtes-vous sûr de vouloir désinstaller &quot;%1&quot; ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
</context>
</TS>